function [prdData, info] = predict_Sprattus_sprattus(par, data, auxData)
  
  % unpack par, data, auxData
  cPar = parscomp_st(par); vars_pull(par); 
  vars_pull(cPar);  vars_pull(data);  vars_pull(auxData);
   
%% compute temperature correction factors
  TC_am = tempcorr(temp.am, T_ref, T_A);
  TC_Ri = tempcorr(temp.Ri, T_ref, T_A);
  TC_tL_1987 = tempcorr(temp.tL_1987, T_ref, T_A);
  TC_tL = tempcorr(temp.tL_1995, T_ref, T_A);
  TC_LN = tempcorr(temp.LN, T_ref, T_A);

  % life cycle
  pars_tj = [g k l_T v_Hb v_Hj v_Hp];
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B, info] = get_tj(pars_tj, f);

  % birth
  L_b = L_m * l_b;                   % cm, structural length at birth of foetus  at f = 1
  Lw_b = L_b/ del_M;                 % cm, total length at birth
  %Ww_b = L_b^3 * (1 + f * w);       % g, wet weight at birth
  %aT_b = t_b/ k_M/ TC_ab;           % d, age at birth of foetus at f and T
  
  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty at f
  Lw_p = L_p/ del_M;                % cm, total length at puberty at f
  %Ww_p = L_p^3 * (1 + f * w);       % g, wet weight at puberty 
  %aT_p = t_p/ k_M/ TC_ap;           % d, time since birth at puberty at f and T

  % ultimate
  L_i = L_m * l_i;                  % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;                % cm, ultimate total length at f
  %Ww_i = L_i^3 * (1 + f * w);       % g, ultimate wet weight 

  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hj; U_Hp]; % compose parameter vector
  RT_i = TC_Ri * reprod_rate_j(L_i, f, pars_R);                 % ultimate reproduction rate

  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];  % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);      % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC_am;               % d, mean life span at T

  % pack to output
  prdData.am = aT_m;
  prdData.Lb = Lw_b;
  prdData.Lp = Lw_p;
  prdData.Li = Lw_i;
  prdData.Ri = RT_i;

  %% uni-variate data

  EWw = (LW(:,1) * del_M).^3 * (1 + f * w); % g, wet weight at L_w
  
  EN = 30e-3 * TC_LN * reprod_rate_j(LN(:,1) * del_M, f, pars_R);  % #, 10^3 eggs at length

  % tL data
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B] = get_tj(pars_tj, f_tL);
  Lw_b = l_b * L_m/ del_M; Lw_j = l_j * L_m/ del_M; Lw_i = l_i * L_m/ del_M;
  kT_M = k_M * TC_tL_1987; rT_j = rho_j * kT_M;  rT_B = rho_B * kT_M; 
  aT_b = t_b/ kT_M; aT_j = t_j/ kT_M;
  t_j = aT_j - aT_b; % time since birth at metamorphosis
  t_bj = tL_1987(tL_1987(:,1) < t_j,1); % select times between birth & metamorphosis
  EL_bj = Lw_b * exp(t_bj * rT_j/3); % exponential growth as V1-morph
  t_ji = tL_1987(tL_1987(:,1) >= t_j,1); % selects times after metamorphosis
  EL_ji = Lw_i - (Lw_i - Lw_j) * exp( - rT_B * (t_ji - t_j)); % cm, expected length at time
  ELw_1987 = [EL_bj; EL_ji]; % catenate lengths
  
  % 1995/1996 data
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B] = get_tj(pars_tj, f_tL);
  Lw_b = l_b * L_m/ del_M; Lw_j = l_j * L_m/ del_M; Lw_i = l_i * L_m/ del_M; 
  kT_M = k_M * TC_tL; rT_j = rho_j * kT_M;  rT_B = rho_B * kT_M; 
  ELw_1995 = Lw_i - (Lw_i - L0) * exp( - rT_B * tL_1995(:,1)); % cm, expected length at time
  %
  ELw_1996 = Lw_i - (Lw_i - L0) * exp( - rT_B * tL_1996(:,1)); % cm, expected length at time


  % pack to output
  prdData.tL_1987 = ELw_1987;
  prdData.tL_1995 = ELw_1995;
  prdData.tL_1996 = ELw_1996;
  prdData.LW = EWw;
  prdData.LN = EN;
     